==> spip_3.2.11.orig.tar.xz: plugins-dist/forum/lang/forum_id.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=id
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_radio_articles_futurs' => 'untuk artikel yang akan dipublikasikan di masa depan saja (tidak ada aksi di database).',
	'bouton_radio_articles_tous' => 'untuk semua artikel tanpa pengecualian.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'untuk semua artikel, terkecuali artikel yang forumnya dinonaktifkan.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrasi diperlukan (pengguna harus mendaftarkan diri dengan memberikan alamat e-mailnya sebelum dapat berkontribusi).',
	'bouton_radio_moderation_priori' => 'Moderasi awal (
 kontribusi hanya akan ditampilkan setelah validasi
 oleh administrator).', # MODIF
	'bouton_radio_modere_abonnement' => 'registrasi diperlukan',
	'bouton_radio_modere_posteriori' => 'moderasi akhir', # MODIF
	'bouton_radio_modere_priori' => 'moderasi awal', # MODIF
	'bouton_radio_publication_immediate' => 'Publikasi pesan segera
 (kontribusi akan ditampilkan sesegera mungkin setelah dikirimkan, kemudian
 administrator dapat menghapusnya).',

	// F
	'form_pet_message_commentaire' => 'Ada pesan atau komentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Anda tidak memiliki akses ke forum ini lagi.',
	'forum_attention_dix_caracteres' => '<b>Peringatan!</b> Pesan anda hendaknya terdiri dari sepuluh karakter atau lebih.',
	'forum_attention_trois_caracteres' => '<b>Peringatan!</b> Judul anda hendaknya terdiri dari tiga karakter atau lebih.',
	'forum_attention_trop_caracteres' => '<b>Peringatan !</b> pesan anda terlalu panjang (@compte@ karakter) : untuk dapat menyimpannya, pesan tidak boleh lebih dari @max@ karakter.', # MODIF
	'forum_avez_selectionne' => 'Anda telah memilih:',
	'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>di sini</a> untuk lanjut.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Forum ini telah dimoderasi: kontribusi anda hanya akan muncul setelah divalidasi oleh administrator situs.', # MODIF
	'forum_lien_hyper' => '<b>Tautan web</b> (opsional)', # MODIF
	'forum_message_definitif' => 'Pesan akhir: kirim ke situs',
	'forum_message_trop_long' => 'Pesan anda terlalu panjang. Panjang maksimum adalah 20000 karakter.', # MODIF
	'forum_ne_repondez_pas' => 'Jangan balas ke e-mail ini tapi ke forum yang terdapat di alamat berikut:', # MODIF
	'forum_page_url' => '(Jika pesan anda merujuk pada sebuah artikel yang dipublikasi di web atau halaman yang memberikan informasi lebih lanjut, silakan masukkan judul halaman dan URL-nya di bawah).',
	'forum_poste_par' => 'Pesan dikirim@parauteur@ mengikuti artikel anda.', # MODIF
	'forum_qui_etes_vous' => '<b>Siapa anda?</b> (opsional)', # MODIF
	'forum_texte' => 'Teks pesan anda:', # MODIF
	'forum_titre' => 'Subyek:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validasi pilihan ini',
	'forum_voir_avant' => 'Lihat pesan sebelum dikirim', # MODIF
	'forum_votre_email' => 'Alamat e-mail anda:', # MODIF
	'forum_votre_nom' => 'Nama anda (atau alias):', # MODIF
	'forum_vous_enregistrer' => 'Sebelum berpartisipasi di
		forum ini, anda harus mendaftarkan diri. Terima kasih
		telah memasukkan pengidentifikasi pribadi yang
		diberikan pada anda. Jika anda belum terdaftar, anda harus',
	'forum_vous_inscrire' => 'mendaftarkan diri.',

	// I
	'icone_poster_message' => 'Kirim sebuah pesan',
	'icone_suivi_forum' => 'Tindak lanjut dari forum umum: @nb_forums@ kontribusi',
	'icone_suivi_forums' => 'Kelola forum',
	'icone_supprimer_message' => 'Hapus pesan ini',
	'icone_valider_message' => 'Validasi pesan ini',
	'info_activer_forum_public' => '<i>Untuk mengaktifkan forum-forum umum, silakan pilih mode moderasi standar forum-forum tersebut:</I>', # MODIF
	'info_appliquer_choix_moderation' => 'Terapkan pilihan moderasi ini:',
	'info_desactiver_forum_public' => 'Non aktifkan penggunaan forum
	umum. Forum umum dapat digunakan berdasarkan kasus per kasus untuk
	artikel-artikel; dan penggunannya dilarang untuk bagian, berita, dll.',
	'info_envoi_forum' => 'Kirim forum ke penulis artikel',
	'info_fonctionnement_forum' => 'Operasi forum:',
	'info_gauche_suivi_forum_2' => 'Halaman <i>tindak lanjut forum</i> adalah alat bantu pengelola situs anda (bukan area diskusi atau pengeditan). Halaman ini menampilkan semua kontribusi forum umum artikel ini dan mengizinkan anda untuk mengelola kontribusi-kontribusi ini.', # MODIF
	'info_liens_syndiques_3' => 'forum',
	'info_liens_syndiques_4' => 'adalah',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'adalah',
	'info_liens_syndiques_7' => 'validasi tertunda.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mode operasi standar forum-forum umum',
	'info_option_email' => 'Ketika seorang pengunjung situs mengirimkan sebuah pesan ke forum
		yang terasosiasi dengan sebuah artikel, penulis artikel akan diinformasikan
		melalui e-mail. Anda ingin menggunakan opsi ini?', # MODIF
	'info_pas_de_forum' => 'tidak ada forum',
	'item_activer_forum_administrateur' => 'Aktifkan forum administrator',
	'item_desactiver_forum_administrateur' => 'Non aktifkan forum administrator',

	// L
	'lien_reponse_article' => 'Balasan pada artikel',
	'lien_reponse_breve_2' => 'Balasan pada artikel berita',
	'lien_reponse_rubrique' => 'Balasan pada bagian',
	'lien_reponse_site_reference' => 'Balasan pada situs-situs referensi:', # MODIF

	// O
	'onglet_messages_internes' => 'Pesan internal',
	'onglet_messages_publics' => 'Pesan umum',
	'onglet_messages_vide' => 'Pesan tanpa teks',

	// R
	'repondre_message' => 'Balasan pada pesan ini',

	// S
	'statut_original' => 'asli',

	// T
	'titre_cadre_forum_administrateur' => 'Forum pribadi para administrator',
	'titre_cadre_forum_interne' => 'Forum intern',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Tindak lanjut forum',
	'titre_page_forum_suivi' => 'Tindak lanjut forum'
);

==> spip_4.2.13+dfsg.orig.tar.xz: plugins-dist/forum/lang/forum_id.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/forum?lang_cible=id
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_radio_articles_futurs' => 'untuk artikel yang akan dipublikasikan di masa depan saja (tidak ada aksi di database).',
	'bouton_radio_articles_tous' => 'untuk semua artikel tanpa pengecualian.',
	'bouton_radio_articles_tous_sauf_forum_desactive' => 'untuk semua artikel, terkecuali artikel yang forumnya dinonaktifkan.',
	'bouton_radio_enregistrement_obligatoire' => 'Registrasi diperlukan (pengguna harus mendaftarkan diri dengan memberikan alamat e-mailnya sebelum dapat berkontribusi).',
	'bouton_radio_moderation_priori' => 'Moderasi awal (
 kontribusi hanya akan ditampilkan setelah validasi
 oleh administrator).', # MODIF
	'bouton_radio_modere_abonnement' => 'registrasi diperlukan',
	'bouton_radio_modere_posteriori' => 'moderasi akhir', # MODIF
	'bouton_radio_modere_priori' => 'moderasi awal', # MODIF
	'bouton_radio_publication_immediate' => 'Publikasi pesan segera
 (kontribusi akan ditampilkan sesegera mungkin setelah dikirimkan, kemudian
 administrator dapat menghapusnya).',

	// F
	'form_pet_message_commentaire' => 'Ada pesan atau komentar?',
	'forum' => 'Forum',
	'forum_acces_refuse' => 'Anda tidak memiliki akses ke forum ini lagi.',
	'forum_attention_dix_caracteres' => '<b>Peringatan!</b> Pesan anda hendaknya terdiri dari sepuluh karakter atau lebih.',
	'forum_attention_trois_caracteres' => '<b>Peringatan!</b> Judul anda hendaknya terdiri dari tiga karakter atau lebih.',
	'forum_attention_trop_caracteres' => '<b>Peringatan !</b> pesan anda terlalu panjang (@compte@ karakter) : untuk dapat menyimpannya, pesan tidak boleh lebih dari @max@ karakter.', # MODIF
	'forum_avez_selectionne' => 'Anda telah memilih:',
	'forum_cliquer_retour' => 'Klik <a href=\'@retour_forum@\'>di sini</a> untuk lanjut.',
	'forum_forum' => 'forum',
	'forum_info_modere' => 'Forum ini telah dimoderasi: kontribusi anda hanya akan muncul setelah divalidasi oleh administrator situs.', # MODIF
	'forum_lien_hyper' => '<b>Tautan web</b> (opsional)', # MODIF
	'forum_message_definitif' => 'Pesan akhir: kirim ke situs',
	'forum_message_trop_long' => 'Pesan anda terlalu panjang. Panjang maksimum adalah 20000 karakter.', # MODIF
	'forum_ne_repondez_pas' => 'Jangan balas ke e-mail ini tapi ke forum yang terdapat di alamat berikut:', # MODIF
	'forum_page_url' => '(Jika pesan anda merujuk pada sebuah artikel yang dipublikasi di web atau halaman yang memberikan informasi lebih lanjut, silakan masukkan judul halaman dan URL-nya di bawah).',
	'forum_poste_par' => 'Pesan dikirim@parauteur@ mengikuti artikel anda.', # MODIF
	'forum_qui_etes_vous' => '<b>Siapa anda?</b> (opsional)', # MODIF
	'forum_texte' => 'Teks pesan anda:', # MODIF
	'forum_titre' => 'Subyek:', # MODIF
	'forum_url' => 'URL:', # MODIF
	'forum_valider' => 'Validasi pilihan ini',
	'forum_voir_avant' => 'Lihat pesan sebelum dikirim', # MODIF
	'forum_votre_email' => 'Alamat e-mail anda:', # MODIF
	'forum_votre_nom' => 'Nama anda (atau alias):', # MODIF
	'forum_vous_enregistrer' => 'Sebelum berpartisipasi di
		forum ini, anda harus mendaftarkan diri. Terima kasih
		telah memasukkan pengidentifikasi pribadi yang
		diberikan pada anda. Jika anda belum terdaftar, anda harus',
	'forum_vous_inscrire' => 'mendaftarkan diri.',

	// I
	'icone_poster_message' => 'Kirim sebuah pesan',
	'icone_suivi_forum' => 'Tindak lanjut dari forum umum: @nb_forums@ kontribusi',
	'icone_suivi_forums' => 'Kelola forum',
	'icone_supprimer_message' => 'Hapus pesan ini',
	'icone_valider_message' => 'Validasi pesan ini',
	'info_activer_forum_public' => '<i>Untuk mengaktifkan forum-forum umum, silakan pilih mode moderasi standar forum-forum tersebut:</I>', # MODIF
	'info_appliquer_choix_moderation' => 'Terapkan pilihan moderasi ini:',
	'info_desactiver_forum_public' => 'Non aktifkan penggunaan forum
	umum. Forum umum dapat digunakan berdasarkan kasus per kasus untuk
	artikel-artikel; dan penggunannya dilarang untuk bagian, berita, dll.',
	'info_envoi_forum' => 'Kirim forum ke penulis artikel',
	'info_fonctionnement_forum' => 'Operasi forum:',
	'info_gauche_suivi_forum_2' => 'Halaman <i>tindak lanjut forum</i> adalah alat bantu pengelola situs anda (bukan area diskusi atau pengeditan). Halaman ini menampilkan semua kontribusi forum umum artikel ini dan mengizinkan anda untuk mengelola kontribusi-kontribusi ini.', # MODIF
	'info_liens_syndiques_3' => 'forum',
	'info_liens_syndiques_4' => 'adalah',
	'info_liens_syndiques_5' => 'forum',
	'info_liens_syndiques_6' => 'adalah',
	'info_liens_syndiques_7' => 'validasi tertunda.',
	'info_mode_fonctionnement_defaut_forum_public' => 'Mode operasi standar forum-forum umum',
	'info_option_email' => 'Ketika seorang pengunjung situs mengirimkan sebuah pesan ke forum
		yang terasosiasi dengan sebuah artikel, penulis artikel akan diinformasikan
		melalui e-mail. Anda ingin menggunakan opsi ini?', # MODIF
	'info_pas_de_forum' => 'tidak ada forum',
	'item_activer_forum_administrateur' => 'Aktifkan forum administrator',
	'item_desactiver_forum_administrateur' => 'Non aktifkan forum administrator',

	// L
	'lien_reponse_article' => 'Balasan pada artikel',
	'lien_reponse_breve_2' => 'Balasan pada artikel berita',
	'lien_reponse_rubrique' => 'Balasan pada bagian',
	'lien_reponse_site_reference' => 'Balasan pada situs-situs referensi:', # MODIF

	// O
	'onglet_messages_internes' => 'Pesan internal',
	'onglet_messages_publics' => 'Pesan umum',
	'onglet_messages_vide' => 'Pesan tanpa teks',

	// R
	'repondre_message' => 'Balasan pada pesan ini',

	// S
	'statut_original' => 'asli',

	// T
	'titre_cadre_forum_administrateur' => 'Forum pribadi para administrator',
	'titre_cadre_forum_interne' => 'Forum intern',
	'titre_forum' => 'Forum',
	'titre_forum_suivi' => 'Tindak lanjut forum',
	'titre_page_forum_suivi' => 'Tindak lanjut forum',
];
